Struct AccountId
pub struct AccountId(/* private fields */);Expand description
NEAR Account Identifier.
This is a unique, syntactically valid, human-readable account identifier on the NEAR network.
See the crate-level docs for information about validation.
Also see Error kind precedence.
Examples
use near_account_id::AccountId;
let alice: AccountId = "alice.near".parse().unwrap();
assert!("ƒelicia.near".parse::<AccountId>().is_err()); // (ƒ is not f)Implementations
impl AccountId
impl AccountId
pub fn validate(account_id: &str) -> Result<(), ParseAccountError>
pub fn validate(account_id: &str) -> Result<(), ParseAccountError>
Validates a string as a well-structured NEAR Account ID.
Checks Account ID validity without constructing an AccountId instance.
Examples
use near_account_id::{AccountId, ParseErrorKind};
assert!(AccountId::validate("alice.near").is_ok());
assert!(
matches!(
AccountId::validate("ƒelicia.near"), // fancy ƒ!
Err(err) if err.kind() == &ParseErrorKind::InvalidChar
)
);Error kind precedence
If an Account ID has multiple format violations, the first one would be reported.
Examples
use near_account_id::{AccountId, ParseErrorKind};
assert!(
matches!(
AccountId::validate("A__ƒƒluent."),
Err(err) if err.kind() == &ParseErrorKind::InvalidChar
)
);
assert!(
matches!(
AccountId::validate("a__ƒƒluent."),
Err(err) if err.kind() == &ParseErrorKind::RedundantSeparator
)
);
assert!(
matches!(
AccountId::validate("aƒƒluent."),
Err(err) if err.kind() == &ParseErrorKind::InvalidChar
)
);
assert!(
matches!(
AccountId::validate("affluent."),
Err(err) if err.kind() == &ParseErrorKind::RedundantSeparator
)
);Methods from Deref<Target = AccountIdRef>
pub const MIN_LEN: usize = crate::validation::MIN_LEN
pub const MAX_LEN: usize = crate::validation::MAX_LEN
pub fn as_str(&self) -> &str
pub fn as_str(&self) -> &str
Returns a string slice of the entire Account ID.
Examples
use near_account_id::AccountIdRef;
let carol = AccountIdRef::new("carol.near").unwrap();
assert_eq!("carol.near", carol.as_str());pub fn is_top_level(&self) -> bool
pub fn is_top_level(&self) -> bool
Returns true if the account ID is a top-level NEAR Account ID.
See Top-level Accounts.
Examples
use near_account_id::AccountIdRef;
let near_tla = AccountIdRef::new("near").unwrap();
assert!(near_tla.is_top_level());
// "alice.near" is a sub account of "near" account
let alice = AccountIdRef::new("alice.near").unwrap();
assert!(!alice.is_top_level());pub fn sub_account(
&self,
name: impl AsRef<str>,
) -> Result<AccountId, ParseAccountError>
pub fn sub_account( &self, name: impl AsRef<str>, ) -> Result<AccountId, ParseAccountError>
Returns sub account of current account: {name}.{parent}.
Returns Err if the resulting sub account is invalid (e.g. too long).
Examples
use near_account_id::AccountIdRef;
let parent = AccountIdRef::new("near").unwrap();
let child = parent.sub_account("alice").unwrap();
assert!(child.is_sub_account_of(parent));pub fn parent(&self) -> Option<&AccountIdRef>
pub fn parent(&self) -> Option<&AccountIdRef>
Returns parent account if current account is a subaccount.
Examples
use near_account_id::AccountIdRef;
let tla = AccountIdRef::new("near").unwrap();
assert_eq!(tla.parent(), None);
let child = AccountIdRef::new("alice.near").unwrap();
let parent = child.parent().unwrap();
assert_eq!(parent, "near");
assert!(child.is_sub_account_of(parent));pub fn is_sub_account_of(&self, parent: impl AsRef<AccountIdRef>) -> bool
pub fn is_sub_account_of(&self, parent: impl AsRef<AccountIdRef>) -> bool
Returns true if the AccountId is a direct sub-account of the provided parent account.
See Subaccounts.
Examples
use near_account_id::AccountId;
let near_tla: AccountId = "near".parse().unwrap();
assert!(near_tla.is_top_level());
let alice: AccountId = "alice.near".parse().unwrap();
assert!(alice.is_sub_account_of(&near_tla));
let alice_app: AccountId = "app.alice.near".parse().unwrap();
// While app.alice.near is a sub account of alice.near,
// app.alice.near is not a sub account of near
assert!(alice_app.is_sub_account_of(&alice));
assert!(!alice_app.is_sub_account_of(&near_tla));pub fn get_account_type(&self) -> AccountType
pub fn get_account_type(&self) -> AccountType
Returns AccountType::EthImplicitAccount if the AccountId is a 40 characters long hexadecimal prefixed with ‘0x’.
Returns AccountType::NearImplicitAccount if the AccountId is a 64 characters long hexadecimal.
Otherwise, returns AccountType::NamedAccount.
See Implicit-Accounts.
Examples
use near_account_id::{AccountId, AccountType};
let alice: AccountId = "alice.near".parse().unwrap();
assert!(alice.get_account_type() == AccountType::NamedAccount);
let eth_rando = "0xb794f5ea0ba39494ce839613fffba74279579268"
.parse::<AccountId>()
.unwrap();
assert!(eth_rando.get_account_type() == AccountType::EthImplicitAccount);
let near_rando = "98793cd91a3f870fb126f66285808c7e094afcfc4eda8a970f6648cdf0dbd6de"
.parse::<AccountId>()
.unwrap();
assert!(near_rando.get_account_type() == AccountType::NearImplicitAccount);pub fn is_system(&self) -> bool
pub fn is_system(&self) -> bool
Returns true if this AccountId is the system account.
See System account.
Examples
use near_account_id::AccountId;
let alice: AccountId = "alice.near".parse().unwrap();
assert!(!alice.is_system());
let system: AccountId = "system".parse().unwrap();
assert!(system.is_system());pub fn get_parent_account_id(&self) -> Option<&AccountIdRef>
pub fn get_parent_account_id(&self) -> Option<&AccountIdRef>
Returns parent’s account id reference
Examples
use near_account_id::AccountIdRef;
let alice: &AccountIdRef = AccountIdRef::new_or_panic("alice.near");
let parent: &AccountIdRef = alice.get_parent_account_id().unwrap();
assert!(alice.is_sub_account_of(parent));
let near: &AccountIdRef = AccountIdRef::new_or_panic("near");
assert!(near.get_parent_account_id().is_none());
let implicit: &AccountIdRef = AccountIdRef::new_or_panic("248e104d1d4764d713c4211c13808c8fc887869c580f4178e60538ac5c2a0b26");
assert!(implicit.get_parent_account_id().is_none());Trait Implementations
impl AccountIdExt for AccountId
impl AccountIdExt for AccountId
fn is_implicit(&self) -> bool
fn is_implicit(&self) -> bool
fn is_evm_implicit(&self) -> bool
fn is_evm_implicit(&self) -> bool
impl Arbitrary<'_> for AccountId
impl Arbitrary<'_> for AccountId
fn arbitrary(u: &mut Unstructured<'_>) -> Result<AccountId, Error>
fn arbitrary(u: &mut Unstructured<'_>) -> Result<AccountId, Error>
Self from the given unstructured data. Read morefn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
fn arbitrary_take_rest(u: Unstructured<'a>) -> Result<Self, Error>
Self from the entirety of the given
unstructured data. Read moreimpl AsRef<AccountIdRef> for AccountId
impl AsRef<AccountIdRef> for AccountId
fn as_ref(&self) -> &AccountIdRef
fn as_ref(&self) -> &AccountIdRef
impl Borrow<AccountIdRef> for AccountId
impl Borrow<AccountIdRef> for AccountId
fn borrow(&self) -> &AccountIdRef
fn borrow(&self) -> &AccountIdRef
impl BorshDeserialize for AccountId
impl BorshDeserialize for AccountId
fn deserialize_reader<R>(rd: &mut R) -> Result<AccountId, Error>where
R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSchema for AccountId
impl BorshSchema for AccountId
fn declaration() -> String
fn declaration() -> String
fn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
fn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
impl<'de> Deserialize<'de> for AccountId
impl<'de> Deserialize<'de> for AccountId
fn deserialize<D>(
deserializer: D,
) -> Result<AccountId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<AccountId, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
impl<'a> From<&'a AccountIdRef> for AccountId
impl<'a> From<&'a AccountIdRef> for AccountId
fn from(id: &'a AccountIdRef) -> AccountId
fn from(id: &'a AccountIdRef) -> AccountId
impl From<AccountId> for GlobalContractId
impl From<AccountId> for GlobalContractId
fn from(account_id: AccountId) -> GlobalContractId
fn from(account_id: AccountId) -> GlobalContractId
impl<'a> From<Cow<'a, AccountIdRef>> for AccountId
impl<'a> From<Cow<'a, AccountIdRef>> for AccountId
fn from(value: Cow<'a, AccountIdRef>) -> AccountId
fn from(value: Cow<'a, AccountIdRef>) -> AccountId
impl IntoContractId for &AccountId
impl IntoContractId for &AccountId
fn into_contract_id(self, _chain_id: &ChainId) -> Result<AccountId, Error>
fn into_contract_id(self, _chain_id: &ChainId) -> Result<AccountId, Error>
AccountId for the given chain.impl IntoContractId for AccountId
impl IntoContractId for AccountId
fn into_contract_id(self, _chain_id: &ChainId) -> Result<AccountId, Error>
fn into_contract_id(self, _chain_id: &ChainId) -> Result<AccountId, Error>
AccountId for the given chain.impl IntoGlobalContractId for &AccountId
impl IntoGlobalContractId for &AccountId
fn into_identifier(self) -> GlobalContractId
impl IntoGlobalContractId for AccountId
impl IntoGlobalContractId for AccountId
fn into_identifier(self) -> GlobalContractId
impl JsonSchema for AccountId
Available on crate feature schemars-v0_8 only.
impl JsonSchema for AccountId
schemars-v0_8 only.fn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read morefn schema_name() -> String
fn schema_name() -> String
fn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
impl Ord for AccountId
impl Ord for AccountId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
impl<'a> PartialEq<&'a AccountIdRef> for AccountId
impl<'a> PartialEq<&'a AccountIdRef> for AccountId
fn eq(&self, other: &&'a AccountIdRef) -> bool
fn eq(&self, other: &&'a AccountIdRef) -> bool
self and other values to be equal, and is used by ==.impl<'a> PartialEq<AccountId> for &'a AccountIdRef
impl<'a> PartialEq<AccountId> for &'a AccountIdRef
impl PartialEq<AccountId> for AccountIdRef
impl PartialEq<AccountId> for AccountIdRef
impl PartialEq<AccountIdRef> for AccountId
impl PartialEq<AccountIdRef> for AccountId
impl<'a> PartialOrd<&'a AccountIdRef> for AccountId
impl<'a> PartialOrd<&'a AccountIdRef> for AccountId
impl<'a> PartialOrd<&'a str> for AccountId
impl<'a> PartialOrd<&'a str> for AccountId
impl<'a> PartialOrd<AccountId> for &'a AccountIdRef
impl<'a> PartialOrd<AccountId> for &'a AccountIdRef
impl<'a> PartialOrd<AccountId> for &'a str
impl<'a> PartialOrd<AccountId> for &'a str
impl PartialOrd<AccountId> for AccountIdRef
impl PartialOrd<AccountId> for AccountIdRef
impl PartialOrd<AccountId> for str
impl PartialOrd<AccountId> for str
impl PartialOrd<AccountIdRef> for AccountId
impl PartialOrd<AccountIdRef> for AccountId
impl PartialOrd<String> for AccountId
impl PartialOrd<String> for AccountId
impl PartialOrd<str> for AccountId
impl PartialOrd<str> for AccountId
impl PartialOrd for AccountId
impl PartialOrd for AccountId
impl Serialize for AccountId
impl Serialize for AccountId
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
impl Eq for AccountId
impl StructuralPartialEq for AccountId