AccountIdRef

Struct AccountIdRef 

pub struct AccountIdRef(/* private fields */);
Account identifier. This is the human readable UTF-8 string which is used internally to index accounts on the network and their respective state.

This is the “referenced” version of the account ID. It is to AccountId what str is to String, and works quite similarly to Path. Like with str and Path, you can’t have a value of type AccountIdRef, but you can have a reference like &AccountIdRef or &mut AccountIdRef.

This type supports zero-copy deserialization offered by serde, but cannot do the same for borsh since the latter does not support zero-copy.

Examples

use near_account_id::{AccountId, AccountIdRef};
use std::convert::{TryFrom, TryInto};

// Construction
let alice = AccountIdRef::new("alice.near").unwrap();
assert!(AccountIdRef::new("invalid.").is_err());

Implementations



impl AccountIdRef

pub const MIN_LEN: usize = crate::validation::MIN_LEN

Shortest valid length for a NEAR Account ID.

pub const MAX_LEN: usize = crate::validation::MAX_LEN

Longest valid length for a NEAR Account ID.

pub fn new<S>(id: &S) -> Result<&AccountIdRef, ParseAccountError>
where S: AsRef<str> + ?Sized,

Construct a &AccountIdRef from a string reference.

This constructor validates the provided ID, and will produce an error when validation fails.

pub const fn new_or_panic(id: &str) -> &AccountIdRef

Construct a &AccountIdRef from with validation at compile time. This constructor will panic if validation fails.

use near_account_id::AccountIdRef;
const ALICE: &AccountIdRef = AccountIdRef::new_or_panic("alice.near");

pub fn as_bytes(&self) -> &[u8]

Returns a reference to the account ID bytes.

pub fn as_str(&self) -> &str

Returns a string slice of the entire Account ID.

Examples
use near_account_id::AccountIdRef;

let carol = AccountIdRef::new("carol.near").unwrap();
assert_eq!("carol.near", carol.as_str());

pub fn is_top_level(&self) -> bool

Returns true if the account ID is a top-level NEAR Account ID.

See Top-level Accounts.

Examples
use near_account_id::AccountIdRef;

let near_tla = AccountIdRef::new("near").unwrap();
assert!(near_tla.is_top_level());

// "alice.near" is a sub account of "near" account
let alice = AccountIdRef::new("alice.near").unwrap();
assert!(!alice.is_top_level());

pub fn sub_account( &self, name: impl AsRef<str>, ) -> Result<AccountId, ParseAccountError>

Returns sub account of current account: {name}.{parent}.

Returns Err if the resulting sub account is invalid (e.g. too long).

Examples
use near_account_id::AccountIdRef;

let parent = AccountIdRef::new("near").unwrap();
let child = parent.sub_account("alice").unwrap();

assert!(child.is_sub_account_of(parent));

pub fn parent(&self) -> Option<&AccountIdRef>

Returns parent account if current account is a subaccount.

Examples
use near_account_id::AccountIdRef;

let tla = AccountIdRef::new("near").unwrap();
assert_eq!(tla.parent(), None);

let child = AccountIdRef::new("alice.near").unwrap();
let parent = child.parent().unwrap();

assert_eq!(parent, "near");
assert!(child.is_sub_account_of(parent));

pub fn is_sub_account_of(&self, parent: impl AsRef<AccountIdRef>) -> bool

Returns true if the AccountId is a direct sub-account of the provided parent account.

See Subaccounts.

Examples
use near_account_id::AccountId;

let near_tla: AccountId = "near".parse().unwrap();
assert!(near_tla.is_top_level());

let alice: AccountId = "alice.near".parse().unwrap();
assert!(alice.is_sub_account_of(&near_tla));

let alice_app: AccountId = "app.alice.near".parse().unwrap();

// While app.alice.near is a sub account of alice.near,
// app.alice.near is not a sub account of near
assert!(alice_app.is_sub_account_of(&alice));
assert!(!alice_app.is_sub_account_of(&near_tla));

pub fn get_account_type(&self) -> AccountType

Returns AccountType::EthImplicitAccount if the AccountId is a 40 characters long hexadecimal prefixed with ‘0x’. Returns AccountType::NearImplicitAccount if the AccountId is a 64 characters long hexadecimal. Otherwise, returns AccountType::NamedAccount.

See Implicit-Accounts.

Examples
use near_account_id::{AccountId, AccountType};

let alice: AccountId = "alice.near".parse().unwrap();
assert!(alice.get_account_type() == AccountType::NamedAccount);

let eth_rando = "0xb794f5ea0ba39494ce839613fffba74279579268"
    .parse::<AccountId>()
    .unwrap();
assert!(eth_rando.get_account_type() == AccountType::EthImplicitAccount);

let near_rando = "98793cd91a3f870fb126f66285808c7e094afcfc4eda8a970f6648cdf0dbd6de"
    .parse::<AccountId>()
    .unwrap();
assert!(near_rando.get_account_type() == AccountType::NearImplicitAccount);

pub fn is_system(&self) -> bool

Returns true if this AccountId is the system account.

See System account.

Examples
use near_account_id::AccountId;

let alice: AccountId = "alice.near".parse().unwrap();
assert!(!alice.is_system());

let system: AccountId = "system".parse().unwrap();
assert!(system.is_system());

pub const fn len(&self) -> usize

Returns the length of the underlying account id string.

pub fn get_parent_account_id(&self) -> Option<&AccountIdRef>

Returns parent’s account id reference

Examples
use near_account_id::AccountIdRef;

let alice: &AccountIdRef = AccountIdRef::new_or_panic("alice.near");
let parent: &AccountIdRef = alice.get_parent_account_id().unwrap();

assert!(alice.is_sub_account_of(parent));

let near: &AccountIdRef = AccountIdRef::new_or_panic("near");

assert!(near.get_parent_account_id().is_none());

let implicit: &AccountIdRef = AccountIdRef::new_or_panic("248e104d1d4764d713c4211c13808c8fc887869c580f4178e60538ac5c2a0b26");

assert!(implicit.get_parent_account_id().is_none());