Struct Gas
pub struct Gas { /* private fields */ }Implementations
impl NearGas
impl NearGas
pub const fn from_pgas(inner: u64) -> NearGas
pub const fn from_pgas(inner: u64) -> NearGas
Creates a new NearGas from the specified number of whole peta Gas.
Examples
use near_gas::NearGas;
let tera_gas = NearGas::from_pgas(1);
assert_eq!(tera_gas.as_gas(), 1_000_000_000_000_000);pub const fn from_tgas(inner: u64) -> NearGas
pub const fn from_tgas(inner: u64) -> NearGas
Creates a new NearGas from the specified number of whole tera Gas.
Examples
use near_gas::NearGas;
let tera_gas = NearGas::from_tgas(5);
assert_eq!(tera_gas.as_gas(), 5 * 1_000_000_000_000);pub const fn from_ggas(inner: u64) -> NearGas
pub const fn from_ggas(inner: u64) -> NearGas
Creates a new NearGas from the specified number of whole giga Gas.
Examples
use near_gas::NearGas;
let giga_gas = NearGas::from_ggas(5);
assert_eq!(giga_gas.as_gas(), 5 * 1_000_000_000);pub const fn from_gas(inner: u64) -> NearGas
pub const fn from_gas(inner: u64) -> NearGas
Creates a new NearGas from the specified number of whole Gas.
Examples
use near_gas::NearGas;
let gas = NearGas::from_gas(5 * 1_000_000_000_000);
assert_eq!(gas.as_tgas(), 5);pub const fn is_zero(&self) -> bool
pub const fn is_zero(&self) -> bool
Returns whether the gas value is zero.
Examples
assert!(NearGas::from_gas(0).is_zero());
assert!(!NearGas::from_gas(1).is_zero());pub const fn as_gas(self) -> u64
pub const fn as_gas(self) -> u64
Returns the total number of whole Gas contained by this NearGas.
Examples
use near_gas::NearGas;
let neargas = NearGas::from_gas(12345);
assert_eq!(neargas.as_gas(), 12345);pub const fn as_ggas(self) -> u64
pub const fn as_ggas(self) -> u64
Returns the total number of a whole part of giga Gas contained by this NearGas.
Examples
use near_gas::NearGas;
let neargas = NearGas::from_gas(1 * 1_000_000_000);
assert_eq!(neargas.as_ggas(), 1);pub const fn as_tgas(self) -> u64
pub const fn as_tgas(self) -> u64
Returns the total number of a whole part of tera Gas contained by this NearGas.
Examples
use near_gas::NearGas;
let neargas = NearGas::from_gas(1 * 1_000_000_000_000);
assert_eq!(neargas.as_tgas(), 1);pub const fn as_pgas(self) -> u64
pub const fn as_pgas(self) -> u64
Returns the total number of a whole part of peta Gas contained by this NearGas.
Examples
use near_gas::NearGas;
let neargas = NearGas::from_gas(1 * 1_000_000_000_000_000);
assert_eq!(neargas.as_pgas(), 1);pub const fn checked_add(self, rhs: NearGas) -> Option<NearGas>
pub const fn checked_add(self, rhs: NearGas) -> Option<NearGas>
Checked integer addition. Computes self + rhs, returning None if overflow occurred.
Examples
use near_gas::NearGas;
use std::u64;
assert_eq!(NearGas::from_gas(u64::MAX -2).checked_add(NearGas::from_gas(2)), Some(NearGas::from_gas(u64::MAX)));
assert_eq!(NearGas::from_gas(u64::MAX -2).checked_add(NearGas::from_gas(3)), None);pub const fn checked_sub(self, rhs: NearGas) -> Option<NearGas>
pub const fn checked_sub(self, rhs: NearGas) -> Option<NearGas>
Checked integer subtraction. Computes self - rhs, returning None if overflow occurred.
Examples
use near_gas::NearGas;
assert_eq!(NearGas::from_gas(2).checked_sub(NearGas::from_gas(2)), Some(NearGas::from_gas(0)));
assert_eq!(NearGas::from_gas(2).checked_sub(NearGas::from_gas(3)), None);pub const fn checked_mul(self, rhs: u64) -> Option<NearGas>
pub const fn checked_mul(self, rhs: u64) -> Option<NearGas>
Checked integer multiplication. Computes self * rhs, returning None if overflow occurred.
Examples
use near_gas::NearGas;
use std::u64;
assert_eq!(NearGas::from_gas(2).checked_mul(2), Some(NearGas::from_gas(4)));
assert_eq!(NearGas::from_gas(u64::MAX).checked_mul(2), None)pub const fn checked_div(self, rhs: u64) -> Option<NearGas>
pub const fn checked_div(self, rhs: u64) -> Option<NearGas>
Checked integer division. Computes self / rhs, returning None if rhs == 0.
Examples
use near_gas::NearGas;
assert_eq!(NearGas::from_gas(10).checked_div(2), Some(NearGas::from_gas(5)));
assert_eq!(NearGas::from_gas(2).checked_div(0), None);pub const fn saturating_add(self, rhs: NearGas) -> NearGas
pub const fn saturating_add(self, rhs: NearGas) -> NearGas
Saturating integer addition. Computes self + rhs, saturating at the numeric bounds instead of overflowing.
Examples
use near_gas::NearGas;
assert_eq!(NearGas::from_gas(5).saturating_add(NearGas::from_gas(5)), NearGas::from_gas(10));
assert_eq!(NearGas::from_gas(u64::MAX).saturating_add(NearGas::from_gas(1)), NearGas::from_gas(u64::MAX));pub const fn saturating_sub(self, rhs: NearGas) -> NearGas
pub const fn saturating_sub(self, rhs: NearGas) -> NearGas
Saturating integer subtraction. Computes self - rhs, saturating at the numeric bounds instead of overflowing.
Examples
use near_gas::NearGas;
assert_eq!(NearGas::from_gas(5).saturating_sub(NearGas::from_gas(2)), NearGas::from_gas(3));
assert_eq!(NearGas::from_gas(1).saturating_sub(NearGas::from_gas(2)), NearGas::from_gas(0));pub const fn saturating_mul(self, rhs: u64) -> NearGas
pub const fn saturating_mul(self, rhs: u64) -> NearGas
Saturating integer multiplication. Computes self * rhs, saturating at the numeric bounds instead of overflowing.
Examples
use near_gas::NearGas;
use std::u64;
assert_eq!(NearGas::from_gas(2).saturating_mul(5), NearGas::from_gas(10));
assert_eq!(NearGas::from_gas(u64::MAX).saturating_mul(2), NearGas::from_gas(u64::MAX));pub const fn saturating_div(self, rhs: u64) -> NearGas
pub const fn saturating_div(self, rhs: u64) -> NearGas
Saturating integer division. Computes self / rhs, saturating at the numeric bounds instead of overflowing.
Examples
use near_gas::NearGas;
assert_eq!(NearGas::from_gas(10).saturating_div(2), NearGas::from_gas(5));
assert_eq!(NearGas::from_gas(10).saturating_div(0), NearGas::from_gas(0))Trait Implementations
impl<'arbitrary> Arbitrary<'arbitrary> for NearGas
impl<'arbitrary> Arbitrary<'arbitrary> for NearGas
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<NearGas, Error>
fn arbitrary(u: &mut Unstructured<'arbitrary>) -> Result<NearGas, Error>
Self from the given unstructured data. Read morefn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<NearGas, Error>
fn arbitrary_take_rest(u: Unstructured<'arbitrary>) -> Result<NearGas, Error>
Self from the entirety of the given
unstructured data. Read moreimpl BorshDeserialize for NearGas
impl BorshDeserialize for NearGas
fn deserialize_reader<__R>(reader: &mut __R) -> Result<NearGas, Error>where
__R: Read,
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
impl BorshSchema for NearGas
impl BorshSchema for NearGas
fn declaration() -> String
fn declaration() -> String
fn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
fn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
impl<'de> Deserialize<'de> for NearGas
impl<'de> Deserialize<'de> for NearGas
fn deserialize<D>(
deserializer: D,
) -> Result<NearGas, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<NearGas, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
impl Display for NearGas
NearGas Display implementation rounds up the gas usage to the relevant precision point.
There are 4 breakpoints:
impl Display for NearGas
NearGas Display implementation rounds up the gas usage to the relevant precision point. There are 4 breakpoints:
- exactly 0 Tgas
- <0.001 Tgas
- 0.001 - 0.999 Tgas (uses 3 digits after the floating point)
-
1 Tgas (uses 1 digit after the floating point)
impl JsonSchema for NearGas
Available on crate feature schemars-v0_8 only.
impl JsonSchema for NearGas
schemars-v0_8 only.fn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read morefn schema_name() -> String
fn schema_name() -> String
fn json_schema(_: &mut SchemaGenerator) -> Schema
fn json_schema(_: &mut SchemaGenerator) -> Schema
impl Ord for NearGas
impl Ord for NearGas
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
impl PartialOrd for NearGas
impl PartialOrd for NearGas
impl Serialize for NearGas
impl Serialize for NearGas
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
impl Copy for NearGas
impl Eq for NearGas
impl StructuralPartialEq for NearGas